@@ -26,58 +26,62 @@ from xdg import BaseDirectory
 
 # Application constants
 APP_NAME = 'gWakeOnLAN'
-APP_VERSION = '0.8.1'
-APP_DESCRIPTION = 'Wake up your machines using Wake on LAN.'
-APP_ID = 'gwakeonlan.muflone.com'
-APP_URL = 'https://www.muflone.com/gwakeonlan'
+APP_VERSION = '0.8.4'
+APP_DESCRIPTION = 'Wake up your machines using Wake on LAN'
+APP_DOMAIN = 'gwakeonlan'
 APP_AUTHOR = 'Fabio Castelli'
 APP_AUTHOR_EMAIL = 'muflone@muflone.com'
-APP_COPYRIGHT = 'Copyright 2009-2022 %s' % APP_AUTHOR
-SOURCES_URL = 'https://github.com/muflone/gwakeonlan'
+APP_COPYRIGHT = f'Copyright 2009-2022 {APP_AUTHOR}'
+APP_ID = f'{APP_DOMAIN}.muflone.com'
+URL_AUTHOR = 'https://www.muflone.com/'
+URL_APPLICATION = f'{URL_AUTHOR}{APP_DOMAIN}/'
+URL_SOURCES = f'https://github.com/muflone/{APP_DOMAIN}/'
+URL_TRANSLATIONS = f'https://explore.transifex.com/muflone/{APP_DOMAIN}/'
 # Other constants
-DEFAULT_UDP_PORT = 9
-BROADCAST_ADDRESS = '255.255.255.255'
-DOMAIN_NAME = 'gwakeonlan'
 VERBOSE_LEVEL_QUIET = 0
 VERBOSE_LEVEL_NORMAL = 1
 VERBOSE_LEVEL_MAX = 2
+DEFAULT_UDP_PORT = 9
+BROADCAST_ADDRESS = '255.255.255.255'
 
 # Paths constants
 path_xdg_data_home = pathlib.Path(BaseDirectory.xdg_data_home)
-if ((pathlib.Path('data') / 'gwakeonlan.png')).is_file():
+icon_name = f'{APP_DOMAIN}.png'
+if (pathlib.Path('data') / icon_name).is_file():
     # Use relative paths
     DIR_PREFIX = pathlib.Path('data').parent.absolute()
     DIR_LOCALE = DIR_PREFIX / 'locale'
     DIR_DOCS = DIR_PREFIX / 'doc'
-elif (path_xdg_data_home / DOMAIN_NAME / 'data' / 'gwakeonlan.png').is_file():
+elif (path_xdg_data_home / APP_DOMAIN / 'data' / icon_name).is_file():
     # Use local user path
-    DIR_PREFIX = path_xdg_data_home / DOMAIN_NAME
+    DIR_PREFIX = path_xdg_data_home / APP_DOMAIN
     DIR_LOCALE = path_xdg_data_home / 'locale'
-    DIR_DOCS = path_xdg_data_home / 'doc' / DOMAIN_NAME
-elif (pathlib.Path(__file__).parent.parent / 'share' / DOMAIN_NAME / 'data' /
-      'gwakeonlan.png').is_file():
+    DIR_DOCS = path_xdg_data_home / 'doc' / APP_DOMAIN
+elif (pathlib.Path(__file__).parent.parent / 'share' / APP_DOMAIN / 'data' /
+      icon_name).is_file():
     # Use local user path in the local Python directory
-    DIR_PREFIX = pathlib.Path(__file__).parent.parent / 'share' / DOMAIN_NAME
+    DIR_PREFIX = pathlib.Path(__file__).parent.parent / 'share' / APP_DOMAIN
     DIR_LOCALE = DIR_PREFIX.parent / 'locale'
-    DIR_DOCS = DIR_PREFIX.parent / 'doc' / DOMAIN_NAME
+    DIR_DOCS = DIR_PREFIX.parent / 'doc' / APP_DOMAIN
 else:
     # Use system path
     path_prefix = pathlib.Path(sys.prefix)
-    DIR_PREFIX = path_prefix / 'share' / DOMAIN_NAME
+    DIR_PREFIX = path_prefix / 'share' / APP_DOMAIN
     DIR_LOCALE = path_prefix / 'share' / 'locale'
-    DIR_DOCS = path_prefix / 'share' / 'doc' / DOMAIN_NAME
+    DIR_DOCS = path_prefix / 'share' / 'doc' / APP_DOMAIN
 # Set the paths for the folders
 DIR_DATA = DIR_PREFIX / 'data'
+DIR_ICONS = DIR_DATA / 'icons'
 DIR_UI = DIR_PREFIX / 'ui'
 try:
     # In read-only environments, the settings folder cannot be created
-    # (eg in a Debian pbuilder fakeroot)
-    DIR_SETTINGS = pathlib.Path(BaseDirectory.save_config_path(DOMAIN_NAME))
-except Exception:
+    # (e.g. in a Debian pbuilder fakeroot)
+    DIR_SETTINGS = pathlib.Path(BaseDirectory.save_config_path(APP_DOMAIN))
+except PermissionError:
     # Get the settings path without actually creating it
-    DIR_SETTINGS = pathlib.Path(BaseDirectory.xdg_config_home) / DOMAIN_NAME
+    DIR_SETTINGS = pathlib.Path(BaseDirectory.xdg_config_home) / APP_DOMAIN
 # Set the paths for the data files
-FILE_ICON = DIR_DATA / 'gwakeonlan.png'
+FILE_ICON = DIR_DATA / icon_name
 FILE_CONTRIBUTORS = DIR_DOCS / 'contributors'
 FILE_TRANSLATORS = DIR_DOCS / 'translators'
 FILE_LICENSE = DIR_DOCS / 'license'
